%ifarch aarch64
%global nativearch arm64
%else
%global nativearch %{_arch}
%endif
%global debug_package %{nil}
%bcond_without bootstrap

Summary:        Java library for handling console input
Name:           jline
Version:        3.23.0
Release:        6%{?dist}
License:        BSD-3-Clause
URL:            https://github.com/jline/jline3
Source0:        %{url}/archive/jline-parent-%{version}.tar.gz

Patch5000:      support-ppc64le.patch

%if %{without bootstrap}
BuildRequires: mvn(org.junit.jupiter:junit-jupiter) mvn(org.junit.jupiter:junit-jupiter-params)
BuildRequires: mvn(info.picocli:picocli-codegen) mvn(junit:junit) mvn(org.apiguardian:apiguardian-api) mvn(org.codehaus.mojo:exec-maven-plugin)
%endif
BuildRequires: mvn(org.codehaus.mojo:build-helper-maven-plugin) mvn(org.easymock:easymock) mvn(org.fusesource.jansi:jansi)
BuildRequires: mvn(org.apache.sshd:sshd-core) >= 2.6.0 mvn(org.apache.sshd:sshd-scp) >= 2.6.0 mvn(org.apache.sshd:sshd-sftp) >= 2.6.0
BuildRequires: mvn(org.apache.felix:maven-bundle-plugin) mvn(org.apache.maven.plugins:maven-dependency-plugin) mvn(org.apache.maven.plugins:maven-enforcer-plugin) mvn(org.apache.maven.plugins:maven-source-plugin)
BuildRequires: gcc maven-local mvn(com.googlecode.juniversalchardet:juniversalchardet) mvn(net.java.dev.jna:jna)

ExclusiveArch:  %{java_arches}

%description
JLine is a Java library for handling console input.  It is similar in
functionality to BSD editline and GNU readline but with additional
features that bring it in par with the ZSH line editor.  Those familiar
with the readline/editline capabilities for modern shells (such as bash
and tcsh) will find most of the command editing features of JLine to be
familiar.

%javadoc_package

%package        parent
Summary:        Parent POM for Java library for handling console input
BuildArch:      noarch
Provides:       jline = %{version}-%{release}

%description    parent 
This package contains the parent POM for the jline project

%package        native
Summary:        JLine native library

%description    native 
This package contains a native library for JLine.

%package        terminal
Summary:        JLine terminal
BuildArch:      noarch
Requires:       %{name}-native = %{version}-%{release}

%description    terminal 
This package contains the basic terminal support for JLine.

%package        terminal-jansi
Summary:        JLine terminal with JANSI
BuildArch:      noarch
Requires:       %{name}-terminal = %{version}-%{release}

%description    terminal-jansi 
This package contains a functioning terminal based on JANSI.

%package        terminal-jna
Summary:        JLine terminal with JNA
BuildArch:      noarch
Requires:       %{name}-terminal = %{version}-%{release}

%description    terminal-jna 
This package contains a functioning terminal based on JNA.

%package        reader
Summary:        JLine reader
BuildArch:      noarch
Requires:       %{name}-terminal = %{version}-%{release}

%description    reader 
This package supports reading lines from a console with customizable key
bindings and input editing.

%package        style
Summary:        JLine style processor
BuildArch:      noarch
Requires:       %{name}-terminal = %{version}-%{release}

%description    style 
This package contains a style processor for JLine, which can apply
colors to strings, for example.

%package        builtins
Summary:        JLine builtins
BuildArch:      noarch
Requires:       %{name}-reader = %{version}-%{release}
Requires:       %{name}-style = %{version}-%{release}
Recommends:     mvn(com.googlecode.juniversalchardet:juniversalchardet)

%description    builtins 
This package contains keybindings to emulate popular tools such as nano
and less.

%package        console
Summary:        JLine console
BuildArch:      noarch
Requires:       %{name}-builtins = %{version}-%{release}
Requires:       %{name}-style = %{version}-%{release}

%description    console 
This package contains a console with command and script execution
support, and tab completion.

%package        remote-ssh
Summary:        JLine remote SSH
BuildArch:      noarch
Requires:       %{name}-builtins = %{version}-%{release}
Recommends:     mvn(org.apache.sshd:sshd-core) >= 2.6.0
Recommends:     mvn(org.apache.sshd:sshd-scp) >= 2.6.0
Recommends:     mvn(org.apache.sshd:sshd-sftp) >= 2.6.0

%description    remote-ssh 
This package contains an ssh client.

%package        remote-telnet
Summary:        JLine remote telnet
BuildArch:      noarch
Requires:       %{name}-builtins = %{version}-%{release}
Recommends:     mvn(org.apache.sshd:sshd-core) >= 2.6.0

%description    remote-telnet 
This package contains a telnet client.

%prep
%autosetup -n jline3-jline-parent-%{version} -p1

%pom_remove_parent
%pom_disable_module jline
%pom_disable_module demo
%pom_disable_module groovy
%pom_disable_module graal
%pom_remove_plugin :gmavenplus-plugin
%pom_remove_dep :graal-sdk
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-release-plugin
%pom_remove_plugin :native-image-maven-plugin
%pom_remove_plugin :spotless-maven-plugin

%if %{with bootstrap}
%pom_remove_plugin :exec-maven-plugin native
%endif

%pom_add_dep org.apiguardian:apiguardian-api:1.1.2:test native

sed -i 's/\(JNI_VERSION_1_\)2/\18/' native/src/main/native/jlinenative.c

rm -fr native/src/main/resources/org/jline/nativ/{FreeBSD,Mac,Windows}
rm -fr native/src/main/resources/org/jline/nativ/Linux/*

%build
mkdir native/src/main/resources/org/jline/nativ/Linux/%{nativearch}
cd native/src/main/native
gcc %{build_cflags} -fPIC -fvisibility=hidden -shared -I. \
  -I %{_jvmdir}/java/include -I %{_jvmdir}/java/include/linux %{build_ldflags} \
  -o ../resources/org/jline/nativ/Linux/%{nativearch}/libjlinenative.so \
  jlinenative.c
cd -

%if %{with bootstrap}
%mvn_build -f -s
%else
%mvn_build -s
%endif

%install
%mvn_install

%files parent -f .mfiles-jline-parent
%license LICENSE.txt
%doc changelog.md README.md

%files native -f .mfiles-jline-native
%license LICENSE.txt
%doc changelog.md README.md

%files terminal -f .mfiles-jline-terminal

%files terminal-jansi -f .mfiles-jline-terminal-jansi

%files terminal-jna -f .mfiles-jline-terminal-jna

%files reader -f .mfiles-jline-reader

%files style -f .mfiles-jline-style

%files builtins -f .mfiles-jline-builtins

%files console -f .mfiles-jline-console

%files remote-ssh -f .mfiles-jline-remote-ssh

%files remote-telnet -f .mfiles-jline-remote-telnet

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.23.0-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.23.0-5
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.23.0-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.23.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 26 2023 cunshunxia <cunshunxia@tencent.com> - 3.23.0-2
- move exclusive arch down.

* Wed Apr 26 2023 cunshunxia <cunshunxia@tencent.com> - 3.23.0-1
- initial build
